@@ -12,7 +12,7 @@ cd "$cloneDir"
 go mod edit -replace=gitlab.com/gitlab-org/labkit="$CI_PROJECT_DIR"
 
 # Ensure go.mod and go.sum are up to date in the cloned repo, otherwise build may fail.
-go mod tidy
+go mod tidy -compat=1.18
 
 make -j "$(nproc)"
 
