@@ -1,7 +1,7 @@
 package log
 
 import (
-	"io/ioutil"
+	"io"
 	"testing"
 	"time"
 
@@ -11,7 +11,7 @@ import (
 
 func TestAccessLogFormatter_Format(t *testing.T) {
 	discardLogger := log.New()
-	discardLogger.Out = ioutil.Discard
+	discardLogger.Out = io.Discard
 
 	tests := []struct {
 		name  string
