@@ -10,7 +10,7 @@ import (
 
 var logger = logrus.StandardLogger()
 
-func init() {
+func init() { //nolint:gochecknoinits
 	// Enfore our own defaults on the logrus stdlogger
 	logger.Out = os.Stderr
 	logger.Formatter = &logrus.TextFormatter{}
