@@ -3,6 +3,7 @@ package monitoring
 import (
 	"net"
 	"net/http"
+	"runtime/debug"
 	"testing"
 	"time"
 
@@ -190,6 +191,38 @@ func Test_applyOptions(t *testing.T) {
 			wantServeMux:              http.NewServeMux(),
 			wantServer:                &http.Server{},
 		},
+		{
+			name: "Go build information",
+			opts: []Option{
+				WithGoBuildInformation(&debug.BuildInfo{
+					GoVersion: "1.18",
+					Path:      "gitlab.com/gitlab-org/labkit",
+					Main: debug.Module{
+						Version: "1.0.0",
+					},
+					Settings: []debug.BuildSetting{
+						{Key: "vcs.revision", Value: "61b68cb5bb5c906a89bf3009e5f229caaccb6317"},
+						{Key: "vcs.modified", Value: "false"},
+						{Key: "vcs.time", Value: "2018-01-02T00:00:00Z"},
+					},
+				}),
+			},
+			wantListenerCheck:   checkDefaultListener,
+			wantGathererCheck:   checkDefaultGatherer,
+			wantRegistererCheck: checkDefaultRegisterer,
+			wantbuildInfoGaugeLabels: prometheus.Labels{
+				"committed":      "2018-01-02T00:00:00Z",
+				"go_version":     "1.18",
+				"module_path":    "gitlab.com/gitlab-org/labkit",
+				"module_version": "1.0.0",
+				"modified":       "false",
+				"version":        "61b68cb5bb5c906a89bf3009e5f229caaccb6317",
+			},
+			wantVersion:               "61b68cb5bb5c906a89bf3009e5f229caaccb6317",
+			wantMetricsHandlerPattern: "/metrics",
+			wantServeMux:              http.NewServeMux(),
+			wantServer:                &http.Server{},
+		},
 		{
 			name: "combined",
 			opts: []Option{
