@@ -1,10 +1,12 @@
-#!/usr/bin/env bash
+#!/usr/bin/env sh
 
-set -euo pipefail
-IFS=$'\n\t'
+set -eux
 
-SCRIPT_DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
-cd "${SCRIPT_DIR}"
+IFS="$(printf '\n\t')"
+
+dir=$(cd -- "$(dirname -- "$0")" && pwd)
+
+cd "${dir}"
 
 for build_tags in \
   "" \
@@ -12,11 +14,10 @@ for build_tags in \
   "continuous_profiler_stackdriver" \
   ; do
   (
-    set -x;
 
     go test \
     -race \
-    -tags "${build_tags}" \
+    -tags "${build_tags} ${REQUIRED_BUILD_TAGS:-}" \
     ./...
   )
 done
